# Copyright (C) 2000 Bruce Guenter <bruceg@em.ca>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

import string
import sys

def iif(cond, true, false):
    '''A functional equivalent to C's ?: operator.

    This function returns the value of 'true' if 'cond' evaluates to non-zero,
    or the value of 'false' otherwise.  Since it's a function, both 'true' and
    'false' are unconditionally evaluated (unlike 'cond?true:false' in C).
    '''
    if cond:
        return true
    else:
        return false

def escape(str, escapes):
    for (needle, replacement) in escapes:
        str = string.replace(str, needle, replacement)
    return str

html_escapes = ( ('&', '&amp;'),
                 ('<', '&lt;'),
                 ('>', '&gt;'),
                 ('"', '&quot;') )

def escape_html(str): return escape(str, html_escapes)

url_escapes = ( ('%', '%25'),
                (' ', '%20'),
                ('&', '%26'),
                ('?', '%3f'),
                (':', '%3a'),
                (';', '%3b'),
                ('+', '%2b') )

def escape_url(str):  return escape(str, url_escapes)

def map_range(varname, start, end = None, step = 1):
	if end is None:
		end = start
		start = 0
	return map(lambda i,var=varname:{var:i}, range(start, end, step))

exports = {
    'iif': iif,
    'escape': escape,
    'html': escape_html,
	'map_range': map_range,
    'url': escape_url,
    }
